Method: PageObject#in_frame
- Defined in:
- lib/page-object.rb
#in_frame(identifier, frame = nil, &block) ⇒ Object
Identify an element as existing within a frame. A frame parameter is passed to the block and must be passed to the other calls to PageObject. You can nest calls to in_frame by passing the frame to the next level.
296 297 298 |
# File 'lib/page-object.rb', line 296 def in_frame(identifier, frame=nil, &block) platform.in_frame(identifier, frame, &block) end |